@@ -1,7 +1,7 @@
 from .opengl_classes import *
 import glfw
 import math
-import matplotlib.pyplot as plt
+
 
 # Module enums
 EDGE_MODE_ZERO = 0
@@ -70,19 +70,18 @@ def init():
     glfw.make_context_current(window)
 
     # compile shaders
-    shader_dir = os.path.join(os.path.dirname(__file__))+"\\shaders\\"
-    cs_butterfly = Shader(shader_dir + "butterflytexture.glsl")
-    cs_cosft = Shader(shader_dir + "cos_filter.glsl")
-    cs_fft = Shader(shader_dir + "fft.glsl")
-    cs_fft_pi = Shader(shader_dir + "fft_inversion_permutation.glsl")
-    cs_multiply = Shader(shader_dir + "fft_phase_correlation.glsl")
-    cs_resample = Shader(shader_dir + "resample_image.glsl")
-
-    cs_fft_single = Shader(shader_dir + "fft_single.glsl")
-    cs_fft_pi_single = Shader(shader_dir + "fft_inversion_permutation_single.glsl")
-    cs_multiply_single = Shader(shader_dir + "fft_phase_correlation_single.glsl")
-    cs_copy_r_to_rg = Shader(shader_dir + "copy_r_to_rg.glsl")
-    cs_cosft_single = Shader(shader_dir + "cos_filter_r.glsl")
+    shader_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)),"shaders")
+    cs_butterfly = Shader(os.path.join(shader_dir, "butterflytexture.glsl"))
+    cs_cosft = Shader(os.path.join(shader_dir, "cos_filter.glsl"))
+    cs_fft = Shader(os.path.join(shader_dir, "fft.glsl"))
+    cs_fft_pi = Shader(os.path.join(shader_dir, "fft_inversion_permutation.glsl"))
+    cs_multiply = Shader(os.path.join(shader_dir, "fft_phase_correlation.glsl"))
+    cs_resample = Shader(os.path.join(shader_dir, "resample_image.glsl"))
+    cs_fft_single = Shader(os.path.join(shader_dir, "fft_single.glsl"))
+    cs_fft_pi_single = Shader(os.path.join(shader_dir, "fft_inversion_permutation_single.glsl"))
+    cs_multiply_single = Shader(os.path.join(shader_dir, "fft_phase_correlation_single.glsl"))
+    cs_copy_r_to_rg = Shader(os.path.join(shader_dir, "copy_r_to_rg.glsl"))
+    cs_cosft_single = Shader(os.path.join(shader_dir, "cos_filter_r.glsl"))
 
 
 def set_image_size(size):
@@ -183,6 +182,7 @@ def detect_subpixel_maximum(pcorr, mode):
 def sample_texture_with_shift(texture, shift, edge_mode=EDGE_MODE_ZERO, interpolation_mode=INTERPOLATION_MODE_LINEAR):
     """
     Identical to sample_image_with_shift(), except requires manual uploading of pixeldata to a texture and takes the texture as argument.
+    When using pyGPUreg in an application with multiple openGL contexts, use of this functions requires manual context managing as well.
     """
     texture.bind()
     # set edge and interpolation mode for that texture
@@ -220,6 +220,8 @@ def sample_texture_with_shift(texture, shift, edge_mode=EDGE_MODE_ZERO, interpol
     resampled = glGetTexImage(GL_TEXTURE_2D, 0, GL_RED, GL_FLOAT)
     glMemoryBarrier(GL_TEXTURE_FETCH_BARRIER_BIT)
 
+    resampled = np.reshape(resampled, (height, width))
+
     return resampled
 
 
@@ -577,4 +579,3 @@ def register_to_template(image, apply_shift=True, edge_mode=EDGE_MODE_ZERO, subp
     if window is not None:
         glfw.make_context_current(previous_context)
     return resampled, (dx, dy)
-
